@@ -8,7 +8,6 @@ class Peptides(object):
     ::
 
         >>> p = Peptides()
-        >>> p.get_fasta_sequence("Q8IYB3")
         >>> p.get_peptide_position("Q8IYB3", "VPKPEPIPEPKEPSPE")
         189
 
@@ -25,9 +24,11 @@ class Peptides(object):
         self.sequences = {}
 
     def get_fasta_sequence(self, uniprot_name):
-        seq = self.u.get_fasta_sequence(uniprot_name)
+        seq = self.u.get_fasta(uniprot_name)
+        seq = "".join(seq.split("\n")[1:])
         return seq
 
+
     def get_phosphosite_position(self, uniprot_name, peptide):
         if uniprot_name not in self.sequences.keys():
             seq = self.get_fasta_sequence(uniprot_name)
