@@ -5,16 +5,15 @@ class Mapping(object):
     """
 
 
-        Could use unichem, uniprot, kegg, chembldb
-        Could be HGNC
+    Could use unichem, uniprot, kegg, chembldb
+    Could be HGNC
 
 
     """
 
-
     def __init__(self):
         self._uniprot = UniProt()
-        self._mapping['uniprot'] = self._uniprot._mapping
+        self._mapping["uniprot"] = self._uniprot._mapping
         self.databases = {}
 
     def map(self):
